==> foundation-design-system-0.0.1.tgz: package/gulpfile.js <==
const _ = require('lodash')
const fs = require('fs')
const path = require('path')
const theo = require('theo')
const gulp = require('gulp')

const paths = {
  tokens: './tokens',
  generated: './dist'
}

function getPath (p) {
  return path.resolve(__dirname, p)
}

function cleanOutput(output) {
  return output
    .replace(/^    /gm, '')
    .replace(/^\s*\n/gm, '')
    .trim()
}

theo.registerFormat('scss', (json, options) => {
  return json.propKeys.map(key => {
    var prop = json.props[key]
    return `$${prop.name}: ${prop.value};`
  }).join('\n')
})

theo.registerFormat('js', (json) => {
  var values = _.map(json.props, prop => {
    var name = prop.name
    var value = prop.value
    switch (typeof value) {
      case 'string':
      default:
        value = `"${value}"`
    }
    return `"${name}": ${value},`
  }).join('\n  ').replace(/,$/, '')
  var output = `
    module.exports = {
      ${values}
    };
  `
  return cleanOutput(output)
})

gulp.task('generate-scss', function () {
  return gulp.src(getPath('./tokens/*.yml'))
    .pipe(theo.plugins.transform('web'))
    .pipe(theo.plugins.format('scss'))
    .pipe(gulp.dest(path.resolve(paths.generated)))
})

gulp.task('generate-js', function () {
  return gulp.src(getPath('./tokens/*.yml'))
    .pipe(theo.plugins.transform('web'))
    .pipe(theo.plugins.format('js'))
    .pipe(gulp.dest(path.resolve(paths.generated)))
})

gulp.task('watch', function () {
  gulp.watch(getPath('./tokens/*.yml'), ['generate-scss', 'generate-js'])
})

gulp.task('default', ['generate-scss', 'generate-js'], function (done) {
  console.log('done.')
  done()
})

==> foundation-design-system-0.0.2.tgz: package/gulpfile.js <==
const _ = require('lodash')
const fs = require('fs')
const path = require('path')
const theo = require('theo')
const gulp = require('gulp')
const serve = require('gulp-serve')

const paths = {
  tokens: './tokens',
  generated: './dist'
}

function getPath (p) {
  return path.resolve(__dirname, p)
}

function cleanOutput(output) {
  return output
    .replace(/^    /gm, '')
    .replace(/^\s*\n/gm, '')
    .trim()
}

theo.registerFormat('scss', (json, options) => {
  return json.propKeys.map(key => {
    var prop = json.props[key]
    return `$${prop.name}: ${prop.value};`
  }).join('\n')
})

theo.registerFormat('js', (json) => {
  var values = _.map(json.props, prop => {
    var name = prop.name
    var value = prop.value
    switch (typeof value) {
      case 'string':
      default:
        value = `"${value}"`
    }
    return `"${name}": ${value},`
  }).join('\n  ').replace(/,$/, '')
  var output = `
    module.exports = {
      ${values}
    };
  `
  return cleanOutput(output)
})

gulp.task('generate-scss', function () {
  return gulp.src(getPath('./tokens/*.yml'))
    .pipe(theo.plugins.transform('web'))
    .pipe(theo.plugins.format('scss'))
    .pipe(gulp.dest(path.resolve(paths.generated)))
})

gulp.task('generate-js', function () {
  return gulp.src(getPath('./tokens/*.yml'))
    .pipe(theo.plugins.transform('web'))
    .pipe(theo.plugins.format('js'))
    .pipe(gulp.dest(path.resolve(paths.generated)))
})

gulp.task('serve', serve('sites'))

gulp.task('watch', ['serve'], function () {
  gulp.watch(getPath('./tokens/*.yml'), ['generate-scss', 'generate-js'])
})

gulp.task('default', ['generate-scss', 'generate-js'], function (done) {
  console.log('done.')
  done()
})
